Method: RubyPython::PyObject#callObjectKeywords

Defined in:
lib/rubypython/pyobject.rb

#callObjectKeywords(rbPyArgs, rbPyKeywords) ⇒ Object

Calls the wrapped Python object with the supplied arguments and keyword arguments. Returns a PyObject wrapper around the returned object, which may be NULL.

rbPyArgs

A PyObject wrapping a Tuple of the supplied arguments.

rbPyKeywords

A PyObject wrapping a Dict of keyword arguments.



106
107
108
109
# File 'lib/rubypython/pyobject.rb', line 106

def callObjectKeywords(rbPyArgs, rbPyKeywords)
  pyReturn = RubyPython::Python.PyObject_Call(@pointer, rbPyArgs.pointer, rbPyKeywords.pointer)
  self.class.new pyReturn
end