Method: RubyPython::Interpreter#==
- Defined in:
- lib/rubypython/interpreter.rb
#==(other) ⇒ Object
Compare the current Interpreter to the provided Interpreter or configuration hash. A configuration hash will be converted to an Interpreter object before being compared. :python_exe basename is used. If comparing against another Interpreter object, the Interpreter basename and version are used.
24 25 26 27 28 |
# File 'lib/rubypython/interpreter.rb', line 24 def ==(other) other = self.class.new(other) if other.kind_of? Hash return false unless other.kind_of? self.class (self.version == other.version) && (self.version_name == other.version_name) end |